@@ -29,7 +29,7 @@ const xc_func_info_type xc_func_info_hyb_mgga_x_dldf = {
   "Dispersionless Density Functional",
   XC_FAMILY_HYB_MGGA,
   {&xc_ref_Pernal2009_263201, NULL, NULL, NULL, NULL},
-  XC_FLAGS_3D | MAPLE2C_FLAGS,
+  XC_FLAGS_3D | XC_FLAGS_NEEDS_TAU | MAPLE2C_FLAGS,
   1e-15,
   {0, NULL, NULL, NULL, NULL},
   mgga_x_dldf_init, NULL,
